@@ -1,9 +1,11 @@
 package Pod::Plainer;
+use 5.006;
 use strict;
-use if $[ >= 5.011, 'deprecate';
+use warnings;
+use if $] >= 5.011, 'deprecate';
 use Pod::Parser;
 our @ISA = qw(Pod::Parser);
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 our %E = qw( < lt > gt );
  
@@ -54,6 +56,25 @@ and returns the old(er) style with just 'CE<lt>E<gt>';
 This can be used to pre-process Pod before using tools which do not
 recognise the new style Pods.
 
+=head2 METHODS
+
+=over 
+
+=item escape_ltgt
+
+Replace '<' and '>' by 'EE<lt>ltE<gt>' and 'EE<lt>gtE<gt>'.
+
+=item simple_delimiters
+
+Replace delimiters by 'E<lt>' and 'E<gt>'.
+
+=item textblock
+
+Redefine C<textblock> from L<Pod::Parser> to use C<escape_ltgt>
+and C<simple_delimiters>.
+
+=back
+
 =head2 EXPORT
 
 None by default.
@@ -66,5 +87,14 @@ Robin Barker, rmb1@npl.co.uk
 
 See L<Pod::Parser>.
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2009 by Robin Barker
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.10.1 or,
+at your option, any later version of Perl 5 you may have available.
+
 =cut
 
+$Id: Plainer.pm 250 2009-09-20 18:02:00Z rmb1 $
